@@ -19,6 +19,7 @@ from jade.cli.resubmit_jobs import resubmit_jobs
 from jade.cli.show_events import show_events
 from jade.cli.show_results import show_results
 from jade.cli.show_status import show_status
+from jade.cli.spark import spark
 from jade.cli.stats import stats
 from jade.cli.submit_jobs import submit_jobs
 from jade.cli.try_submit_jobs import try_submit_jobs
@@ -59,6 +60,7 @@ cli.add_command(resubmit_jobs)
 cli.add_command(show_events)
 cli.add_command(show_results)
 cli.add_command(show_status)
+cli.add_command(spark)
 cli.add_command(stats)
 cli.add_command(submit_jobs)
 cli.add_command(try_submit_jobs)
