@@ -44,8 +44,7 @@ class SparkMetrics:
             Output directory in which to write files
 
         """
-        if not output_dir.exists():
-            output_dir.mkdir()
+        output_dir.mkdir(exist_ok=True, parents=True)
         apps = self.list_applications()
         results = {"metrics": []}
         for app in apps:
@@ -57,7 +56,7 @@ class SparkMetrics:
             results["metrics"].append(metrics)
 
         filename = output_dir / self.METRICS_FILE
-        dump_data(results, filename)
+        dump_data(results, filename, indent=2)
         logger.info("Recorded metrics in %s", filename)
 
     def list_applications(self):
